%%This project shows how to apply fft on a signal and its physical
% significance.

fSampling = 10000;           %Sampling Frequency
tSampling = 1/fSampling;    %Sampling Time
L = 10000;                   %Length of Signal
t = (0:L-1)*tSampling;      %Time Vector
F = 100;                    %Frequency of Signal

%%Signal without noise
xsig = sin(2*pi*F*t);
subplot(2,1,1)
plot(t,xsig);
grid on;
axis([0 0.1 -1.2 +1.2])
xlabel('\itTime Axis \rightarrow');
ylabel('\itAmplitude \rightarrow');
title('\itxsig(t) of Frequency = 100Hz');
% pause(2);

%%Frequency Transform of the Above Signal
subplot(2,1,2)
NFFT = 2^nextpow2(L);
Xsig = fft(xsig,NFFT)/L;
f1 = fSampling/2*(linspace(0,1,NFFT/2+1));
semilogy(f1,2*abs(Xsig(1:NFFT/2+1)),'r');
grid on
axis([-50 500 10^(-5) 1])
title('\itSingle-Sided Amplitude Spectrum of xsig(t)')
xlabel('\itFrequency (Hz) \rightarrow')
ylabel('|Xsig(f)| dB  \rightarrow');
% pause(2);


%%Addition of Noise in Signal when Signal is Transmitted over some
% transmission medium
xnoise = xsig + 0.45*randn(size(t));
figure;
subplot(2,1,1)
plot(t,xsig);
xlabel('\itTime Axis \rightarrow');
ylabel('\itAmplitude \rightarrow');
title('\itxsig(t) of Frequency = 100Hz');
axis([0 0.1 -2 +2])
grid on
% pause(2);

subplot(2,1,2)
plot(t,xnoise,'r');
xlabel('\itTime Axis \rightarrow');
ylabel('\itAmplitude \rightarrow');
title('\itxnoise(t) of Frequency = 100Hz (Noise Addition)');
axis([0 0.1 -2 +2])
grid on;
% pause(5);

figure;
subplot(2,1,1)
plot(t,xnoise);
grid on;
axis([0 0.1 -2 +2])
xlabel('\itTime Axis \rightarrow');
ylabel('\itAmplitude \rightarrow');
title('\itxnoise(t) of Frequency = 100Hz (Noise Addition)');
% pause(2);

%%Frequency Transform of the Noisy Signal
subplot(2,1,2)
NFFT = 2^nextpow2(L);
XNoise = fft(xnoise,NFFT)/L;
f2 = fSampling/2*(linspace(0,1,NFFT/2+1));
semilogy(f2,2*abs(XNoise(1:NFFT/2+1)),'r');
grid on
axis([-50 500 10^(-5) 1])
title('\itSingle-Sided Amplitude Spectrum of xnoise(t)')
xlabel('\itFrequency (Hz) \rightarrow')
ylabel('|XNoise(f)| dB\rightarrow');
% pause(2);

%Difference Between Two Transforms
figure;
subplot(2,1,1)
semilogy(f1,2*abs(Xsig(1:NFFT/2+1)));
axis([-50 500 10^(-5) 1])
grid on
title('\itSingle-Sided Amplitude Spectrum of xsig(t)')
xlabel('\itFrequency (Hz) \rightarrow')
ylabel('|Xsig(f)| dB\rightarrow');
% pause(1)
subplot(2,1,2)
semilogy(f2,2*abs(XNoise(1:NFFT/2+1)),'r');
axis([-50 500 10^(-5) 1])
grid on
title('\itSingle-Sided Amplitude Spectrum of xnoise(t)')
xlabel('\itFrequency (Hz) \rightarrow')
ylabel('|XNoise(f)| dB\rightarrow');